---
title: <span class="badge builder"></span> ValueMap
---
# <span class="badge builder"></span> ValueMap

## Constructor

```python
ValueMap()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> dashboard.ValueMap
```

### <span class="badge object-method"></span> options

Map with <value_to_match>: ValueMappingResult. For example: { "10": { text: "Perfection!", color: "green" } }

```python
def options(options: dict[str, dashboard.ValueMappingResult]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ValueMap](./object-ValueMap.md)
